==> eam-wshub-proxyclient-11.4-11-sources.jar: net/datastream/schemas/mp_fields/SECURITYFILTER_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour SECURITYFILTER_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="SECURITYFILTER_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EWSDATASPYID"/>
 *         &lt;element name="DATASPYNAME" type="{http://schemas.datastream.net/MP_fields}CODE30_Type" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SECURITYFILTER_Type", propOrder = {
    "ewsdataspyid",
    "dataspyname"
})
public class SECURITYFILTER_Type {

    @XmlElement(name = "EWSDATASPYID")
    protected long ewsdataspyid;
    @XmlElement(name = "DATASPYNAME")
    protected String dataspyname;

    /**
     * Obtient la valeur de la propriété ewsdataspyid.
     * 
     */
    public long getEWSDATASPYID() {
        return ewsdataspyid;
    }

    /**
     * Définit la valeur de la propriété ewsdataspyid.
     * 
     */
    public void setEWSDATASPYID(long value) {
        this.ewsdataspyid = value;
    }

    /**
     * Obtient la valeur de la propriété dataspyname.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDATASPYNAME() {
        return dataspyname;
    }

    /**
     * Définit la valeur de la propriété dataspyname.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDATASPYNAME(String value) {
        this.dataspyname = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_fields/SECURITYFILTER_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for SECURITYFILTER_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SECURITYFILTER_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EWSDATASPYID"/>
 *         &lt;element name="DATASPYNAME" type="{http://schemas.datastream.net/MP_fields}CODE30_Type" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SECURITYFILTER_Type", propOrder = {
    "ewsdataspyid",
    "dataspyname"
})
public class SECURITYFILTER_Type {

    @XmlElement(name = "EWSDATASPYID")
    protected long ewsdataspyid;
    @XmlElement(name = "DATASPYNAME")
    protected String dataspyname;

    /**
     * Gets the value of the ewsdataspyid property.
     * 
     */
    public long getEWSDATASPYID() {
        return ewsdataspyid;
    }

    /**
     * Sets the value of the ewsdataspyid property.
     * 
     */
    public void setEWSDATASPYID(long value) {
        this.ewsdataspyid = value;
    }

    /**
     * Gets the value of the dataspyname property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDATASPYNAME() {
        return dataspyname;
    }

    /**
     * Sets the value of the dataspyname property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDATASPYNAME(String value) {
        this.dataspyname = value;
    }

}
